@@ -54,6 +54,12 @@ AccumMetric <- function(func, dim_argmax = NULL, activation = "no",
     ...
   )
 
+  if(is.null(args$dim_argmax))
+    args$dim_argmax <- NULL
+
+  if(is.null(args$thresh))
+    args$thresh <- NULL
+
   do.call(metrics()$AccumMetric, args)
 
 }
@@ -84,6 +90,12 @@ skm_to_fastai <- function(func, is_class = TRUE, thresh = NULL,
     ...
   )
 
+  if(is.null(args$thresh))
+    args$thresh <- NULL
+
+  if(is.null(args$activation))
+    args$activation <- NULL
+
   do.call(metrics()$skm_to_fastai, args)
 
 }
@@ -215,6 +227,10 @@ APScoreBinary <- function(axis = -1, average = "macro", pos_label = 1, sample_we
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+
   do.call(metrics()$APScoreBinary, args)
 
 }
@@ -237,6 +253,9 @@ BalancedAccuracy <- function(axis = -1, sample_weight = NULL, adjusted = FALSE)
     adjusted = adjusted
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$BalancedAccuracy, args)
 
 }
@@ -260,6 +279,12 @@ BrierScore <- function(axis = -1, sample_weight = NULL, pos_label = NULL) {
     pos_label = pos_label
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$pos_label))
+    args$pos_label <- NULL
+
   do.call(metrics()$BrierScore, args)
 
 }
@@ -285,6 +310,12 @@ CohenKappa <- function(axis = -1, labels = NULL, weights = NULL, sample_weight =
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$weights))
+    args$weights <- NULL
+
   do.call(metrics()$CohenKappa, args)
 
 }
@@ -313,6 +344,9 @@ F1Score <- function(axis = -1, labels = NULL, pos_label = 1, average = "binary",
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$F1Score, args)
 
 }
@@ -345,6 +379,9 @@ FBeta <- function(beta, axis = -1, labels = NULL, pos_label = 1, average = "bina
       sample_weight = sample_weight
     )
 
+    if(is.null(args$sample_weight))
+      args$sample_weight <- NULL
+
     do.call(metrics()$FBeta, args)
   }
 
@@ -366,6 +403,9 @@ HammingLoss <- function(axis = -1, sample_weight = NULL) {
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$HammingLoss, args)
 
 }
@@ -394,6 +434,9 @@ Jaccard <- function(axis = -1, labels = NULL, pos_label = 1,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$Jaccard, args)
 
 }
@@ -422,6 +465,9 @@ Precision <- function(axis = -1, labels = NULL, pos_label = 1,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$Precision, args)
 
 }
@@ -450,6 +496,9 @@ Recall <- function(axis = -1, labels = NULL, pos_label = 1,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$Recall, args)
 
 }
@@ -479,6 +528,12 @@ RocAuc <- function(axis = -1, average = "macro",
     multi_class = multi_class
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$max_fpr))
+    args$max_fpr <- NULL
+
   do.call(metrics()$RocAuc, args)
 
 }
@@ -520,6 +575,13 @@ RocAucBinary <- function(axis = -1, average = "macro",
     multi_class = multi_class
   )
 
+
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$max_fpr))
+    args$max_fpr <- NULL
+
   do.call(metrics()$RocAucBinary, args)
 
 }
@@ -612,6 +674,9 @@ APScoreMulti <- function(sigmoid = TRUE, average = "macro",
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
   do.call(metrics()$APScoreMulti, args)
 
 }
@@ -631,13 +696,21 @@ APScoreMulti <- function(sigmoid = TRUE, average = "macro",
 BrierScoreMulti <- function(thresh = 0.5, sigmoid = TRUE,
                             sample_weight = NULL, pos_label = NULL) {
 
-  metrics()$BrierScoreMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     sample_weight = sample_weight,
     pos_label = pos_label
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$pos_label))
+    args$pos_label <- NULL
+
+  do.call(metrics()$BrierScoreMulti, args)
+
 }
 
 
@@ -658,7 +731,7 @@ F1ScoreMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
                          pos_label = 1, average = "macro",
                          sample_weight = NULL) {
 
-  metrics()$F1ScoreMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     labels = labels,
@@ -667,6 +740,14 @@ F1ScoreMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$labels))
+    args$labels <- NULL
+
+  do.call(metrics()$F1ScoreMulti, args)
+
 }
 
 
@@ -687,7 +768,7 @@ F1ScoreMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
 FBetaMulti <- function(beta, thresh = 0.5, sigmoid = TRUE, labels = NULL,
                        pos_label = 1, average = "macro", sample_weight = NULL) {
 
-  metrics()$FBetaMulti(
+  args = list(
     beta = beta,
     thresh = thresh,
     sigmoid = sigmoid,
@@ -697,6 +778,14 @@ FBetaMulti <- function(beta, thresh = 0.5, sigmoid = TRUE, labels = NULL,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$labels))
+    args$labels <- NULL
+
+  do.call(metrics()$FBetaMulti, args)
+
 }
 
 
@@ -719,7 +808,7 @@ JaccardMulti <- function(thresh = 0.5, sigmoid = TRUE,
                          labels = NULL, pos_label = 1,
                          average = "macro", sample_weight = NULL) {
 
-  python_function_result <- metrics()$JaccardMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     labels = labels,
@@ -728,6 +817,13 @@ JaccardMulti <- function(thresh = 0.5, sigmoid = TRUE,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$labels))
+    args$labels <- NULL
+
+  do.call(metrics()$JaccardMulti, args)
 }
 
 
@@ -743,12 +839,17 @@ JaccardMulti <- function(thresh = 0.5, sigmoid = TRUE,
 #' @export
 MatthewsCorrCoefMulti <- function(thresh = 0.5, sigmoid = TRUE, sample_weight = NULL) {
 
-  metrics()$MatthewsCorrCoefMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  do.call(metrics()$MatthewsCorrCoefMulti, args)
+
 }
 
 
@@ -768,7 +869,7 @@ PrecisionMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
                            pos_label = 1, average = "macro",
                            sample_weight = NULL) {
 
-  metrics()$PrecisionMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     labels = labels,
@@ -777,6 +878,14 @@ PrecisionMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$labels))
+    args$labels <- NULL
+
+  do.call(metrics()$PrecisionMulti, args)
+
 }
 
 #' @title RecallMulti
@@ -796,7 +905,7 @@ RecallMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
                         pos_label = 1, average = "macro",
                         sample_weight = NULL) {
 
-  metrics()$RecallMulti(
+  args = list(
     thresh = thresh,
     sigmoid = sigmoid,
     labels = labels,
@@ -805,6 +914,14 @@ RecallMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$labels))
+    args$labels <- NULL
+
+  do.call(metrics()$RecallMulti, args)
+
 }
 
 #' @title RocAucMulti
@@ -821,13 +938,21 @@ RecallMulti <- function(thresh = 0.5, sigmoid = TRUE, labels = NULL,
 RocAucMulti <- function(sigmoid = TRUE, average = "macro",
                         sample_weight = NULL, max_fpr = NULL) {
 
-  metrics()$RocAucMulti(
+  args = list(
     sigmoid = sigmoid,
     average = average,
     sample_weight = sample_weight,
     max_fpr = max_fpr
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  if(is.null(args$max_fpr))
+    args$max_fpr <- NULL
+
+  do.call(metrics()$RocAucMulti, args)
+
 }
 
 #' @title MSE
@@ -974,10 +1099,15 @@ exp_rmspe <- function(preds, targs) {
 #' @export
 ExplainedVariance <- function(sample_weight = NULL) {
 
-  metrics()$ExplainedVariance(
+  args = list(
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  do.call(metrics()$ExplainedVariance, args)
+
 }
 
 #' @title R2Score
@@ -990,10 +1120,15 @@ ExplainedVariance <- function(sample_weight = NULL) {
 #' @export
 R2Score <- function(sample_weight = NULL) {
 
-  metrics()$R2Score(
+  args = list(
     sample_weight = sample_weight
   )
 
+  if(is.null(args$sample_weight))
+    args$sample_weight <- NULL
+
+  do.call(metrics()$R2Score, args)
+
 }
 
 
@@ -1013,7 +1148,7 @@ R2Score <- function(sample_weight = NULL) {
 PearsonCorrCoef <- function(dim_argmax = NULL, activation = "no",
                             thresh = NULL, to_np = FALSE, invert_arg = FALSE, flatten = TRUE) {
 
-  metrics()$PearsonCorrCoef(
+  args = list(
     dim_argmax = dim_argmax,
     activation = activation,
     thresh = thresh,
@@ -1022,6 +1157,14 @@ PearsonCorrCoef <- function(dim_argmax = NULL, activation = "no",
     flatten = flatten
   )
 
+  if(is.null(args$dim_argmax))
+    args$dim_argmax <- NULL
+
+  if(is.null(args$thresh))
+    args$thresh <- NULL
+
+  do.call(metrics()$PearsonCorrCoef, args)
+
 }
 
 
@@ -1044,7 +1187,7 @@ SpearmanCorrCoef <- function(dim_argmax = NULL, axis = 0, nan_policy = "propagat
                              activation = "no", thresh = NULL, to_np = FALSE,
                              invert_arg = FALSE, flatten = TRUE) {
 
-  python_function_result <- metrics()$SpearmanCorrCoef(
+  args <- list(
     dim_argmax = dim_argmax,
     axis = as.integer(axis),
     nan_policy = nan_policy,
@@ -1055,6 +1198,14 @@ SpearmanCorrCoef <- function(dim_argmax = NULL, axis = 0, nan_policy = "propagat
     flatten = flatten
   )
 
+  if(is.null(args$dim_argmax))
+    args$dim_argmax <- NULL
+
+  if(is.null(args$thresh))
+    args$thresh <- NULL
+
+  do.call(metrics()$SpearmanCorrCoef, args)
+
 }
 
 
@@ -1129,7 +1280,7 @@ JaccardCoeff <- function(axis = 1) {
 #' @export
 CorpusBLEUMetric <- function(vocab_sz = 5000, axis = -1) {
 
-  python_function_result <- metrics()$CorpusBLEUMetric(
+  metrics()$CorpusBLEUMetric(
     vocab_sz = as.integer(vocab_sz),
     axis = as.integer(axis)
   )
